@@ -117,7 +117,7 @@ def build_ssdp_search_packet(
     request_line = "M-SEARCH * HTTP/1.1"
     headers = {
         "HOST": f"{get_host_port_string(ssdp_target)}",
-        "MAN": '"ssdp:discover"',
+        "MAN": SSDP_DISCOVER,
         "MX": f"{ssdp_mx}",
         "ST": f"{ssdp_st}",
     }
@@ -251,7 +251,6 @@ class SsdpProtocol(DatagramProtocol):
 
     def error_received(self, exc: Exception) -> None:
         """Handle an error."""
-        # pylint: disable=no-self-use
         _LOGGER.error("Received error: %s, transport: %s", exc, self.transport)
 
     def connection_lost(self, exc: Optional[Exception]) -> None:
